@@ -1,5 +1,5 @@
 ########################################################################
-# FindBin::libs_curr
+# libs_curr_pm
 #
 # use $FindBin::Bin to search for 'lib' directories and use them.
 #
@@ -19,7 +19,7 @@
 
 package FindBin::libs;
 
-use v5.10;
+use v5.14;
 use strict;
 
 use FindBin;
@@ -75,7 +75,7 @@ BEGIN
 # package variables 
 ########################################################################
 
-our $VERSION = '2.10';
+our $VERSION    = '2.11';
 $VERSION = eval $VERSION;
 
 my %defaultz = 
@@ -203,6 +203,9 @@ my $find_libs
     # (including volume) walking up the path 
     # from $FindBin::Bin -> root.
     #
+    # no libs found is empty list or undef for 
+    # scalar.
+    #
     # passing it back as a list isn't all that
     # painful for a few paths.
 
@@ -330,7 +333,12 @@ sub import
 {
     &$handle_args;
 
-    my @libz = $find_libs->();
+    my @libz = $find_libs->()
+    or do
+    {
+        say 'No libs found';
+        return
+    };
 
     # HAK ALERT: the regex does nothing for security,
     # just dodges -T. putting this down here instead
@@ -383,18 +391,21 @@ sub import
         }
     }
 
+    # no 'else', these are not exclusive
+
     if( defined $argz{ p5lib } )
     {
         # stuff the lib's found at the front of $ENV{ PERL5LIB }
+        # yes, virginia, substr is an lvalue -- and saner than
+        # dealing with \Q and a regex on arbitrary paths.
 
-        ( substr $ENV{ PERL5LIB }, 0, 0 ) = join ':', @libz, ''
-        if @libz;
+        ( substr $ENV{ PERL5LIB }, 0, 0 ) = join ':', @libz, '';
 
         print STDERR "\nUpdated PERL5LIB:\t$ENV{ PERL5LIB }\n"
         if $verbose;
     }
 
-    if( $argz{ use } && @libz )
+    if( $argz{ use } )
     {
         # this obviously won't work if lib ever depends 
         # on the caller's package.
@@ -637,14 +648,12 @@ produces something like
     )
 
 without append @etc will have only ./bar/etc since the array would
-be overwritten with each call to FB::l::import.
+be overwritten with each call to import.
 
 =back
 
 =head3 Subdirectories
 
-=over 4
-
 The "subdir" and "subonly" settings will add or 
 exclusively use subdir's. This is useful if some
 of your lib's are in ../lib/perl5 along with 
@@ -657,7 +666,6 @@ These could be handled with:
 
 which uses the "lib" dir's along with any lib/perl5 dirs.
 
-
 This can also be handy for locating subdir's used
 for configuring packages:
 
